@@ -16,6 +16,9 @@ GType ggit_branch_type_get_type	(void) G_GNUC_CONST;
 #define GGIT_TYPE_FEATURE_FLAGS	(ggit_feature_flags_get_type())
 GType ggit_feature_flags_get_type	(void) G_GNUC_CONST;
 
+#define GGIT_TYPE_DIFF_BINARY_TYPE	(ggit_diff_binary_type_get_type())
+GType ggit_diff_binary_type_get_type	(void) G_GNUC_CONST;
+
 #define GGIT_TYPE_BLAME_FLAGS	(ggit_blame_flags_get_type())
 GType ggit_blame_flags_get_type	(void) G_GNUC_CONST;
 
@@ -76,6 +79,9 @@ GType ggit_status_flags_get_type	(void) G_GNUC_CONST;
 #define GGIT_TYPE_SUBMODULE_IGNORE	(ggit_submodule_ignore_get_type())
 GType ggit_submodule_ignore_get_type	(void) G_GNUC_CONST;
 
+#define GGIT_TYPE_SUBMODULE_RECURSE	(ggit_submodule_recurse_get_type())
+GType ggit_submodule_recurse_get_type	(void) G_GNUC_CONST;
+
 #define GGIT_TYPE_SUBMODULE_STATUS	(ggit_submodule_status_get_type())
 GType ggit_submodule_status_get_type	(void) G_GNUC_CONST;
 
