@@ -35,6 +35,11 @@
 #include <libgit2-glib/ggit-blob-output-stream.h>
 #include <libgit2-glib/ggit-checkout-options.h>
 #include <libgit2-glib/ggit-note.h>
+#include <libgit2-glib/ggit-blame.h>
+#include <libgit2-glib/ggit-cherry-pick-options.h>
+#include <libgit2-glib/ggit-commit.h>
+#include <libgit2-glib/ggit-tree-builder.h>
+#include <libgit2-glib/ggit-remote.h>
 
 G_BEGIN_DECLS
 
@@ -46,14 +51,11 @@ G_BEGIN_DECLS
 #define GGIT_REPOSITORY_GET_CLASS(obj)		(G_TYPE_INSTANCE_GET_CLASS ((obj), GGIT_TYPE_REPOSITORY, GgitRepositoryClass))
 
 typedef struct _GgitRepositoryClass	GgitRepositoryClass;
-typedef struct _GgitRepositoryPrivate	GgitRepositoryPrivate;
 
 struct _GgitRepository
 {
 	/*< private >*/
 	GgitNative parent;
-
-	GgitRepositoryPrivate *priv;
 };
 
 /**
@@ -99,7 +101,6 @@ GgitRef            *ggit_repository_lookup_reference  (GgitRepository        *re
 GgitRef            *ggit_repository_create_reference  (GgitRepository        *repository,
                                                        const gchar           *name,
                                                        GgitOId               *oid,
-                                                       GgitSignature         *signature,
                                                        const gchar           *log_message,
                                                        GError               **error);
 
@@ -107,7 +108,6 @@ GgitRef            *ggit_repository_create_symbolic_reference
                                                       (GgitRepository        *repository,
                                                        const gchar           *name,
                                                        const gchar           *target,
-                                                       GgitSignature         *signature,
                                                        const gchar           *log_message,
                                                        GError               **error);
 
@@ -192,14 +192,15 @@ gboolean            ggit_repository_tag_foreach       (GgitRepository        *re
                                                        gpointer               user_data,
                                                        GError               **error);
 
+GgitTreeBuilder    *ggit_repository_create_tree_builder (
+                                                       GgitRepository        *repository,
+                                                       GError               **error);
+
 GgitTreeBuilder    *ggit_repository_create_tree_builder_from_tree (
                                                        GgitRepository        *repository,
                                                        GgitTree              *tree,
                                                        GError               **error);
 
-GgitTreeBuilder    *ggit_repository_create_tree_builder (
-                                                       GgitRepository        *repository);
-
 GgitIndexEntry     *ggit_repository_create_index_entry_for_file (
                                                        GgitRepository        *repository,
                                                        GFile                 *file,
@@ -223,8 +224,6 @@ GgitBranch         *ggit_repository_create_branch     (GgitRepository        *re
                                                        const gchar           *branch_name,
                                                        GgitObject            *target,
                                                        GgitCreateFlags        flags,
-                                                       GgitSignature         *signature,
-                                                       const gchar           *log_message,
                                                        GError               **error);
 
 GgitBranchEnumerator *ggit_repository_enumerate_branches (GgitRepository        *repository,
@@ -236,7 +235,7 @@ GgitBranch         *ggit_repository_lookup_branch     (GgitRepository        *re
                                                        GgitBranchType         branch_type,
                                                        GError               **error);
 
-GgitRemote         *ggit_repository_get_remote        (GgitRepository        *repository,
+GgitRemote         *ggit_repository_lookup_remote     (GgitRepository        *repository,
                                                        const gchar           *name,
                                                        GError               **error);
 
@@ -248,6 +247,16 @@ GgitRemote         *ggit_repository_create_remote     (GgitRepository        *re
 gchar             **ggit_repository_list_remotes      (GgitRepository        *repository,
                                                        GError               **error);
 
+void                ggit_repository_add_remote_push   (GgitRepository        *repository,
+                                                       GgitRemote            *remote,
+                                                       const gchar           *refspec,
+                                                       GError               **error);
+
+void                ggit_repository_add_remote_fetch  (GgitRepository        *repository,
+                                                       GgitRemote            *remote,
+                                                       const gchar           *refspec,
+                                                       GError               **error);
+
 GgitRef            *ggit_repository_get_head          (GgitRepository        *repository,
                                                        GError               **error);
 
@@ -303,11 +312,35 @@ gboolean            ggit_repository_submodule_foreach  (GgitRepository
                                                         gpointer                 user_data,
                                                         GError                 **error);
 
+void                ggit_repository_set_submodule_ignore (GgitRepository       *repository,
+                                                          const gchar          *name,
+                                                          GgitSubmoduleIgnore   ignore,
+                                                          GError              **error);
+
+void                ggit_repository_set_submodule_update (GgitRepository       *repository,
+                                                          const gchar          *name,
+                                                          GgitSubmoduleUpdate   update,
+                                                          GError              **error);
+
+void                ggit_repository_set_submodule_url  (GgitRepository          *repository,
+                                                        const gchar             *name,
+                                                        const gchar             *url,
+                                                        GError                 **error);
+
+void                ggit_repository_set_submodule_fetch_recurse (GgitRepository        *repository,
+                                                                 const gchar           *name,
+                                                                 GgitSubmoduleRecurse   fetch_recurse_submodules,
+                                                                 GError               **error);
+
+GgitSubmoduleStatus ggit_repository_get_submodule_status (GgitRepository        *repository,
+                                                          const gchar           *name,
+                                                          GgitSubmoduleIgnore    ignore,
+                                                          GError               **error);
+
 void                ggit_repository_reset              (GgitRepository          *repository,
                                                         GgitObject              *target,
                                                         GgitResetType            reset_type,
-                                                        GgitSignature           *signature,
-                                                        const gchar             *log_message,
+                                                        GgitCheckoutOptions     *checkout_options,
                                                         GError                 **error);
 
 void                ggit_repository_reset_default      (GgitRepository          *repository,
@@ -388,13 +421,13 @@ GgitIndex          *ggit_repository_cherry_pick_commit (GgitRepository
                                                         GgitMergeOptions         *merge_options,
                                                         GError                  **error);
 
-const gchar        *ggit_repository_get_default_notes_ref (GgitRepository           *repository,
+gchar              *ggit_repository_get_default_notes_ref (GgitRepository           *repository,
                                                            GError                  **error);
 
 GgitOId            *ggit_repository_create_note        (GgitRepository          *repository,
+                                                        const gchar             *notes_ref,
                                                         GgitSignature           *author,
                                                         GgitSignature           *committer,
-                                                        const gchar             *notes_ref,
                                                         GgitOId                 *id,
                                                         const gchar             *note,
                                                         gboolean                 force,
@@ -417,6 +450,11 @@ gboolean            ggit_repository_note_foreach       (GgitRepository
                                                         GgitNoteCallback         callback,
                                                         gpointer                 user_data,
                                                         GError                 **error);
+gboolean           ggit_repository_path_is_ignored     (GgitRepository          *repository,
+                                                        const gchar             *path,
+                                                        GError                 **error);
+
+G_DEFINE_AUTOPTR_CLEANUP_FUNC (GgitRepository, g_object_unref)
 
 G_END_DECLS
 
