@@ -84,32 +84,36 @@ ggit_submodule_unref (GgitSubmodule *submodule)
 }
 
 /**
- * ggit_submodule_save:
+ * ggit_submodule_open:
  * @submodule: a #GgitSubmodule.
  * @error: a #GError for error reporting, or %NULL.
  *
- * Writes submodule settings to .gitmodules file.
- * Commits any in-memory changes to the submodule to the gitmodules
- * file on disk.  You may also be interested in ggit_submodule_init() which
- * writes submodule info to ".git/config" (which is better for local changes
- * to submodule settings) and/or ggit_submodule_sync() which writes
- * settings about remotes to the actual submodule repository.
+ * Open the repository for a submodule. Multiple calls to this function
+ * will return distinct #GgitRepository objects. Only submodules which are
+ * checked out in the working directory can be opened.
+ *
+ * Returns: (transfer full): the opened #GgitRepository or %NULL in case of an
+ *                           error.
  */
-void
-ggit_submodule_save (GgitSubmodule  *submodule,
-                     GError        **error)
+GgitRepository *
+ggit_submodule_open (GgitSubmodule  *submodule,
+                     GError       **error)
 {
+	git_repository *repo;
 	gint ret;
 
-	g_return_if_fail (submodule != NULL);
-	g_return_if_fail (error == NULL || *error == NULL);
+	g_return_val_if_fail (submodule != NULL, NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
-	ret = git_submodule_save (submodule->submodule);
+	ret = git_submodule_open (&repo, submodule->submodule);
 
 	if (ret != GIT_OK)
 	{
 		_ggit_error_set (error, ret);
+		return NULL;
 	}
+
+	return _ggit_repository_wrap (repo, TRUE);
 }
 
 /**
@@ -180,40 +184,6 @@ ggit_submodule_get_url (GgitSubmodule *submodule)
 	return git_submodule_url (submodule->submodule);
 }
 
-/**
- * ggit_submodule_set_url:
- * @submodule: a #GgitSubmodule.
- * @url: URL that should be used for the submodule.
- * @error: a #GError for error reporting, or %NULL.
- *
- * Sets the URL for the submodule.
- *
- * This sets the URL in memory for the submodule. This will be used for
- * any following submodule actions while this submodule data is in memory.
- *
- * After calling this, you may wish to call ggit_submodule_save() to write
- * the changes back to the ".gitmodules" file and ggit_submodule_sync() to
- * write the changes to the checked out submodule repository.
- */
-void
-ggit_submodule_set_url (GgitSubmodule       *submodule,
-                        const gchar         *url,
-                        GError             **error)
-{
-	gint ret;
-
-	g_return_if_fail (submodule != NULL);
-	g_return_if_fail (error == NULL || *error == NULL);
-
-	ret = git_submodule_set_url (submodule->submodule,
-	                             url);
-
-	if (ret != GIT_OK)
-	{
-		_ggit_error_set (error, ret);
-	}
-}
-
 /**
  * ggit_submodule_get_index_id:
  * @submodule: a #GgitSubmodule.
@@ -303,32 +273,6 @@ ggit_submodule_get_ignore (GgitSubmodule *submodule)
 	return (GgitSubmoduleIgnore)git_submodule_ignore (submodule->submodule);
 }
 
-/**
- * ggit_submodule_set_ignore:
- * @submodule: a #GgitSubmodule.
- * @ignore: a #GgitSubmoduleIgnore.
- *
- * Sets the ignore rule in memory for the submodule.  This will be used
- * for any following actions (such as ggit_submodule_status()) while the
- * submodule is in memory.  You should call ggit_submodule_save() if you
- * want to persist the new ignore role.
- *
- * Calling this again with GGIT_SUBMODULE_IGNORE_DEFAULT or calling
- * ggit_submodule_reload() will revert the rule to the value that was in the
- * original config.
- *
- * Returns: the old #GgitSubmoduleIgnore.
- */
-GgitSubmoduleIgnore
-ggit_submodule_set_ignore (GgitSubmodule       *submodule,
-                           GgitSubmoduleIgnore  ignore)
-{
-	g_return_val_if_fail (submodule != NULL, 0);
-
-	return (GgitSubmoduleIgnore)git_submodule_set_ignore (submodule->submodule,
-	                                                      (git_submodule_ignore_t)ignore);
-}
-
 /**
  * ggit_submodule_get_update:
  * @submodule: a #GgitSubmodule.
@@ -342,31 +286,7 @@ ggit_submodule_get_update (GgitSubmodule *submodule)
 {
 	g_return_val_if_fail (submodule != NULL, 0);
 
-	return (GgitSubmoduleUpdate)git_submodule_update (submodule->submodule);
-}
-
-/**
- * ggit_submodule_set_update:
- * @submodule: a #GgitSubmodule.
- * @update: a #GgitSubmoduleUpdate.
- *
- * Sets the update rule in memory for the submodule.  You should call
- * ggit_submodule_save() if you want to persist the new update rule.
- *
- * Calling this again with GGIT_SUBMODULE_UPDATE_DEFAULT or calling
- * ggit_submodule_reload() will revert the rule to the value that was in the
- * original config.
- *
- * Returns: the old #GgitSubmoduleUpdate.
- */
-GgitSubmoduleUpdate
-ggit_submodule_set_update (GgitSubmodule       *submodule,
-                           GgitSubmoduleUpdate  update)
-{
-	g_return_val_if_fail (submodule != NULL, 0);
-
-	return (GgitSubmoduleUpdate)git_submodule_set_update (submodule->submodule,
-	                                                      (git_submodule_update_t)update);
+	return (GgitSubmoduleUpdate)git_submodule_update_strategy (submodule->submodule);
 }
 
 /**
@@ -385,26 +305,6 @@ ggit_submodule_get_fetch_recurse (GgitSubmodule *submodule)
 	return git_submodule_fetch_recurse_submodules (submodule->submodule);
 }
 
-/**
- * ggit_submodule_set_fetch_recurse:
- * @submodule: a #GgitSubmodule.
- * @fetch_recurse: %TRUE to fetch recurse submodules.
- *
- * Sets the submodule.'name'.fetchRecurseSubmodules value for
- * the submodule.  You should call ggit_submodule_save() if you want
- * to persist the new value.
- *
- * Returns: the old value.
- */
-gboolean
-ggit_submodule_set_fetch_recurse (GgitSubmodule *submodule,
-                                  gboolean       fetch_recurse)
-{
-	g_return_val_if_fail (submodule != NULL, FALSE);
-
-	return git_submodule_set_fetch_recurse_submodules (submodule->submodule, fetch_recurse);
-}
-
 /**
  * ggit_submodule_init:
  * @submodule: a #GgitSubmodule.
@@ -488,38 +388,4 @@ ggit_submodule_reload (GgitSubmodule  *submodule,
 	}
 }
 
-/**
- * ggit_submodule_get_status:
- * @submodule: a #GgitSubmodule.
- * @error: a #GError for error reporting, or %NULL.
- *
- * Gets the status for a submodule.
- * This looks at a submodule and tries to determine the status.  It
- * will return a combination of the %GGIT_SUBMODULE_STATUS values.
- * How deeply it examines the working directory to do this will depend
- * on the #GgitSubmoduleIgnore value for the submodule - which can be
- * set either temporarily or permanently with ggit_submodule_set_ignore().
- *
- * Returns: the #GgitSubmoduleStatus for @submodule.
- */
-GgitSubmoduleStatus
-ggit_submodule_get_status (GgitSubmodule  *submodule,
-                           GError        **error)
-{
-	gint ret;
-	GgitSubmoduleStatus status;
-
-	g_return_val_if_fail (submodule != NULL, 0);
-	g_return_val_if_fail (error == NULL || *error == NULL, 0);
-
-	ret = git_submodule_status (&status, submodule->submodule);
-
-	if (ret != GIT_OK)
-	{
-		_ggit_error_set (error, ret);
-	}
-
-	return status;
-}
-
 /* ex:set ts=8 noet: */
