@@ -38,7 +38,7 @@ GgitSubmodule         *_ggit_submodule_wrap                  (const git_submodul
 GgitSubmodule          *ggit_submodule_ref                   (GgitSubmodule       *submodule);
 void                    ggit_submodule_unref                 (GgitSubmodule       *submodule);
 
-void                    ggit_submodule_save                  (GgitSubmodule       *submodule,
+GgitRepository         *ggit_submodule_open                  (GgitSubmodule       *submodule,
                                                               GError             **error);
 
 GgitRepository         *ggit_submodule_get_owner             (GgitSubmodule       *submodule);
@@ -49,10 +49,6 @@ const gchar            *ggit_submodule_get_path              (GgitSubmodule
 
 const gchar            *ggit_submodule_get_url               (GgitSubmodule       *submodule);
 
-void                    ggit_submodule_set_url               (GgitSubmodule       *submodule,
-                                                              const gchar         *url,
-                                                              GError             **error);
-
 GgitOId                *ggit_submodule_get_index_id          (GgitSubmodule       *submodule);
 
 GgitOId                *ggit_submodule_get_head_id           (GgitSubmodule       *submodule);
@@ -61,19 +57,10 @@ GgitOId                *ggit_submodule_get_workdir_id        (GgitSubmodule
 
 GgitSubmoduleIgnore     ggit_submodule_get_ignore            (GgitSubmodule       *submodule);
 
-GgitSubmoduleIgnore     ggit_submodule_set_ignore            (GgitSubmodule       *submodule,
-                                                              GgitSubmoduleIgnore  ignore);
-
 GgitSubmoduleUpdate     ggit_submodule_get_update            (GgitSubmodule       *submodule);
 
-GgitSubmoduleUpdate     ggit_submodule_set_update            (GgitSubmodule       *submodule,
-                                                              GgitSubmoduleUpdate  update);
-
 gboolean                ggit_submodule_get_fetch_recurse     (GgitSubmodule       *submodule);
 
-gboolean                ggit_submodule_set_fetch_recurse     (GgitSubmodule       *submodule,
-                                                              gboolean             fetch_recurse);
-
 void                    ggit_submodule_init                  (GgitSubmodule       *submodule,
                                                               gboolean             overwrite,
                                                               GError             **error);
@@ -85,8 +72,7 @@ void                    ggit_submodule_reload                (GgitSubmodule
                                                               gboolean             force,
                                                               GError             **error);
 
-GgitSubmoduleStatus     ggit_submodule_get_status            (GgitSubmodule       *submodule,
-                                                              GError             **error);
+G_DEFINE_AUTOPTR_CLEANUP_FUNC (GgitSubmodule, ggit_submodule_unref)
 
 G_END_DECLS
 
