@@ -26,6 +26,9 @@
 /* Must cast the enums to ints to avoid enum compare warning */
 #define ASSERT_ENUM(a, b) G_STATIC_ASSERT (((int) a) == ((int) b))
 
+ASSERT_ENUM (GGIT_DIFF_BINARY_NONE,    GIT_DIFF_BINARY_NONE);
+ASSERT_ENUM (GGIT_DIFF_BINARY_LITERAL, GIT_DIFF_BINARY_LITERAL);
+ASSERT_ENUM (GGIT_DIFF_BINARY_DELTA,   GIT_DIFF_BINARY_DELTA);
 
 ASSERT_ENUM (GGIT_BRANCH_LOCAL,  GIT_BRANCH_LOCAL);
 ASSERT_ENUM (GGIT_BRANCH_REMOTE, GIT_BRANCH_REMOTE);
@@ -119,9 +122,10 @@ ASSERT_ENUM (GGIT_MERGE_FILE_FAVOR_UNION, GIT_MERGE_FILE_FAVOR_UNION);
 
 ASSERT_ENUM (GGIT_MERGE_TREE_FIND_RENAMES, GIT_MERGE_TREE_FIND_RENAMES);
 
-ASSERT_ENUM (GGIT_REMOTE_DOWNLOAD_TAGS_AUTO,  GIT_REMOTE_DOWNLOAD_TAGS_AUTO);
-ASSERT_ENUM (GGIT_REMOTE_DOWNLOAD_TAGS_NONE,  GIT_REMOTE_DOWNLOAD_TAGS_NONE);
-ASSERT_ENUM (GGIT_REMOTE_DOWNLOAD_TAGS_ALL,   GIT_REMOTE_DOWNLOAD_TAGS_ALL);
+ASSERT_ENUM (GGIT_REMOTE_DOWNLOAD_TAGS_UNSPECIFIED, GIT_REMOTE_DOWNLOAD_TAGS_UNSPECIFIED);
+ASSERT_ENUM (GGIT_REMOTE_DOWNLOAD_TAGS_AUTO, GIT_REMOTE_DOWNLOAD_TAGS_AUTO);
+ASSERT_ENUM (GGIT_REMOTE_DOWNLOAD_TAGS_NONE, GIT_REMOTE_DOWNLOAD_TAGS_NONE);
+ASSERT_ENUM (GGIT_REMOTE_DOWNLOAD_TAGS_ALL, GIT_REMOTE_DOWNLOAD_TAGS_ALL);
 
 ASSERT_ENUM (GGIT_REMOTE_COMPLETION_DOWNLOAD, GIT_REMOTE_COMPLETION_DOWNLOAD);
 ASSERT_ENUM (GGIT_REMOTE_COMPLETION_INDEXING, GIT_REMOTE_COMPLETION_INDEXING);
@@ -161,11 +165,16 @@ ASSERT_ENUM (GGIT_STATUS_WORKING_TREE_TYPECHANGE, GIT_STATUS_WT_TYPECHANGE);
 ASSERT_ENUM (GGIT_STATUS_IGNORED,                 GIT_STATUS_IGNORED);
 
 
-ASSERT_ENUM (GGIT_SUBMODULE_IGNORE_RESET,     GIT_SUBMODULE_IGNORE_RESET);
-ASSERT_ENUM (GGIT_SUBMODULE_IGNORE_NONE,      GIT_SUBMODULE_IGNORE_NONE);
+ASSERT_ENUM (GGIT_SUBMODULE_IGNORE_UNSPECIFIED, GIT_SUBMODULE_IGNORE_UNSPECIFIED);
+ASSERT_ENUM (GGIT_SUBMODULE_IGNORE_NONE, GIT_SUBMODULE_IGNORE_NONE);
 ASSERT_ENUM (GGIT_SUBMODULE_IGNORE_UNTRACKED, GIT_SUBMODULE_IGNORE_UNTRACKED);
-ASSERT_ENUM (GGIT_SUBMODULE_IGNORE_DIRTY,     GIT_SUBMODULE_IGNORE_DIRTY);
-ASSERT_ENUM (GGIT_SUBMODULE_IGNORE_ALL,       GIT_SUBMODULE_IGNORE_ALL);
+ASSERT_ENUM (GGIT_SUBMODULE_IGNORE_DIRTY, GIT_SUBMODULE_IGNORE_DIRTY);
+ASSERT_ENUM (GGIT_SUBMODULE_IGNORE_ALL, GIT_SUBMODULE_IGNORE_ALL);
+
+
+ASSERT_ENUM (GGIT_SUBMODULE_RECURSE_NO, GIT_SUBMODULE_RECURSE_NO);
+ASSERT_ENUM (GGIT_SUBMODULE_RECURSE_YES, GIT_SUBMODULE_RECURSE_YES);
+ASSERT_ENUM (GGIT_SUBMODULE_RECURSE_ONDEMAND, GIT_SUBMODULE_RECURSE_ONDEMAND);
 
 
 ASSERT_ENUM (GGIT_SUBMODULE_STATUS_IN_HEAD, GIT_SUBMODULE_STATUS_IN_HEAD);
@@ -184,11 +193,11 @@ ASSERT_ENUM (GGIT_SUBMODULE_STATUS_WD_WD_MODIFIED, GIT_SUBMODULE_STATUS_WD_WD_MO
 ASSERT_ENUM (GGIT_SUBMODULE_STATUS_WD_UNTRACKED, GIT_SUBMODULE_STATUS_WD_UNTRACKED);
 
 
-ASSERT_ENUM (GGIT_SUBMODULE_UPDATE_RESET,    GIT_SUBMODULE_UPDATE_RESET);
 ASSERT_ENUM (GGIT_SUBMODULE_UPDATE_CHECKOUT, GIT_SUBMODULE_UPDATE_CHECKOUT);
 ASSERT_ENUM (GGIT_SUBMODULE_UPDATE_REBASE,   GIT_SUBMODULE_UPDATE_REBASE);
 ASSERT_ENUM (GGIT_SUBMODULE_UPDATE_MERGE,    GIT_SUBMODULE_UPDATE_MERGE);
 ASSERT_ENUM (GGIT_SUBMODULE_UPDATE_NONE,     GIT_SUBMODULE_UPDATE_NONE);
+ASSERT_ENUM (GGIT_SUBMODULE_UPDATE_DEFAULT,  GIT_SUBMODULE_UPDATE_DEFAULT);
 
 ASSERT_ENUM (GGIT_STATUS_OPTION_INCLUDE_UNTRACKED, GIT_STATUS_OPT_INCLUDE_UNTRACKED);
 ASSERT_ENUM (GGIT_STATUS_OPTION_INCLUDE_IGNORED, GIT_STATUS_OPT_INCLUDE_IGNORED);
@@ -220,8 +229,8 @@ ASSERT_ENUM (GGIT_PACKBUILDER_STAGE_DELTAFICATION, GIT_PACKBUILDER_DELTAFICATION
 
 ASSERT_ENUM (GGIT_CHECKOUT_NONE,                    GIT_CHECKOUT_NONE);
 ASSERT_ENUM (GGIT_CHECKOUT_SAFE,                    GIT_CHECKOUT_SAFE);
-ASSERT_ENUM (GGIT_CHECKOUT_SAFE_CREATE,             GIT_CHECKOUT_SAFE_CREATE);
 ASSERT_ENUM (GGIT_CHECKOUT_FORCE,                   GIT_CHECKOUT_FORCE);
+ASSERT_ENUM (GGIT_CHECKOUT_RECREATE_MISSING,        GIT_CHECKOUT_RECREATE_MISSING);
 ASSERT_ENUM (GGIT_CHECKOUT_ALLOW_CONFLICTS,         GIT_CHECKOUT_ALLOW_CONFLICTS);
 ASSERT_ENUM (GGIT_CHECKOUT_REMOVE_UNTRACKED,        GIT_CHECKOUT_REMOVE_UNTRACKED);
 ASSERT_ENUM (GGIT_CHECKOUT_REMOVE_IGNORED,          GIT_CHECKOUT_REMOVE_IGNORED);
@@ -236,6 +245,10 @@ ASSERT_ENUM (GGIT_CHECKOUT_SKIP_LOCKED_DIRECTORIES, GIT_CHECKOUT_SKIP_LOCKED_DIR
 ASSERT_ENUM (GGIT_CHECKOUT_DONT_OVERWRITE_IGNORED,  GIT_CHECKOUT_DONT_OVERWRITE_IGNORED);
 ASSERT_ENUM (GGIT_CHECKOUT_CONFLICT_STYLE_MERGE,    GIT_CHECKOUT_CONFLICT_STYLE_MERGE);
 ASSERT_ENUM (GGIT_CHECKOUT_CONFLICT_STYLE_DIFF3,    GIT_CHECKOUT_CONFLICT_STYLE_DIFF3);
+ASSERT_ENUM (GGIT_CHECKOUT_DONT_REMOVE_EXISTING,    GIT_CHECKOUT_DONT_REMOVE_EXISTING);
+ASSERT_ENUM (GGIT_CHECKOUT_DONT_WRITE_INDEX,        GIT_CHECKOUT_DONT_WRITE_INDEX);
+ASSERT_ENUM (GGIT_CHECKOUT_UPDATE_SUBMODULES,       GIT_CHECKOUT_UPDATE_SUBMODULES);
+ASSERT_ENUM (GGIT_CHECKOUT_UPDATE_SUBMODULES_IF_CHANGED, GIT_CHECKOUT_UPDATE_SUBMODULES_IF_CHANGED);
 
 ASSERT_ENUM (GGIT_CHECKOUT_NOTIFY_NONE,      GIT_CHECKOUT_NOTIFY_NONE);
 ASSERT_ENUM (GGIT_CHECKOUT_NOTIFY_CONFLICT,  GIT_CHECKOUT_NOTIFY_CONFLICT);
